@@ -1,3 +1,6 @@
+__copyright__ = "Copyright (c) 2018 Helium Edu"
+__license__ = "MIT"
+
 import os
 import shutil
 import subprocess
@@ -7,10 +10,6 @@ import git
 
 from .. import utils
 
-__author__ = "Alex Laird"
-__copyright__ = "Copyright 2018, Helium Edu"
-__version__ = "1.5.16"
-
 
 class InitAction:
     def __init__(self):
@@ -19,7 +18,8 @@ class InitAction:
 
     def setup(self, subparsers):
         parser = subparsers.add_parser(self.name, help=self.help)
-        parser.add_argument("--config-only", action="store_true", help="Only initialize the .heliumcli.yml config file")
+        parser.add_argument("--config-only", action="store_true",
+                            help="Only initialize the .heliumcli.yml config file")
         parser.add_argument("id", help="The ID (no spaces) to give to the new project")
         parser.add_argument("name", help="The friendly name to give to the new project")
         parser.add_argument("host", help="The hostname to give the project")
@@ -29,7 +29,8 @@ class InitAction:
     def run(self, args):
         config_path = os.path.abspath(os.environ.get("HELIUMCLI_CONFIG_PATH", ".heliumcli.yml"))
         if os.path.exists(config_path):
-            print("It looks like a helium-cli project already exists in this directory, not doing anything.")
+            print("It looks like a helium-cli project already exists in this directory, "
+                  "not doing anything.")
 
             sys.exit(1)
 
@@ -41,34 +42,52 @@ class InitAction:
         if not args.config_only:
             self._init_project(config_path, args)
         else:
-            self._replace_in_file(os.path.dirname(config_path), os.path.basename(config_path), args)
+            self._replace_in_file(os.path.dirname(config_path),
+                                  os.path.basename(config_path), args)
 
         print("A new helium-cli project has been initialized.")
 
     def _init_project(self, config_path, args):
         project_dir = os.path.join(os.path.dirname(config_path), args.id)
         template_project_name = "template-project"
-        template_version = os.environ.get("HELIUMCLI_TEMPLATE_PROJECT_VERSION", "1.2.0")
+        template_version = os.environ.get("HELIUMCLI_TEMPLATE_PROJECT_VERSION", "latest")
 
-        print("Cloning the template-project {} repo into this directory ...".format(template_version))
-        git.Repo.clone_from("{}/{}.git".format("https://github.com/HeliumEdu", template_project_name),
-                            project_dir,
-                            branch=template_version)
+        print(f"Cloning the template-project with \"{template_version}\" into this directory ...")
+        if template_version == "latest":
+            repo = git.Repo.clone_from(f"https://github.com/HeliumEdu/{template_project_name}.git", project_dir)
+            version_tags = utils.sort_tags(repo.tags)
+            latest_tag = version_tags[-1]
+            repo.git.checkout(latest_tag)
+        else:
+            git.Repo.clone_from(f"https://github.com/HeliumEdu/{template_project_name}.git",
+                                project_dir,
+                                branch=template_version)
 
         shutil.rmtree(os.path.join(project_dir, ".git"))
 
         if os.path.exists(os.path.join(project_dir, ".travis.yml.template")):
             os.remove(os.path.join(project_dir, ".travis.yml"))
-            os.rename(os.path.join(project_dir, ".travis.yml.template"), os.path.join(project_dir, ".travis.yml"))
+            os.rename(os.path.join(project_dir, ".travis.yml.template"),
+                      os.path.join(project_dir, ".travis.yml"))
 
         if os.path.exists(os.path.join(project_dir, ".github", "workflows", "build.yml.template")):
             os.remove(os.path.join(project_dir, ".github", "workflows", "build.yml"))
             os.rename(os.path.join(project_dir, ".github", "workflows", "build.yml.template"),
                       os.path.join(project_dir, ".github", "workflows", "build.yml"))
 
+        if os.path.exists(os.path.join(project_dir, ".github", "workflows", "deploy.yml.template")):
+            os.rename(os.path.join(project_dir, ".github", "workflows", "deploy.yml.template"),
+                      os.path.join(project_dir, ".github", "workflows", "deploy.yml"))
+
         if os.path.exists(os.path.join(project_dir, "Makefile.template")):
             os.remove(os.path.join(project_dir, "Makefile"))
-            os.rename(os.path.join(project_dir, "Makefile.template"), os.path.join(project_dir, "Makefile"))
+            os.rename(os.path.join(project_dir, "Makefile.template"),
+                      os.path.join(project_dir, "Makefile"))
+
+        if os.path.exists(os.path.join(project_dir, "README.md.template")):
+            os.remove(os.path.join(project_dir, "README.md"))
+            os.rename(os.path.join(project_dir, "README.md.template"),
+                      os.path.join(project_dir, "README.md"))
 
         repo = git.Repo.init(project_dir)
 
@@ -80,12 +99,13 @@ class InitAction:
 
         repo.git.add(A=True)
 
-        os.rename(os.path.join(project_dir, "project_id"), os.path.join(project_dir, self._lower_slug))
+        os.rename(os.path.join(project_dir, "project_id"),
+                  os.path.join(project_dir, self._lower_slug))
 
         print("Running make ...")
 
         subprocess.call(["python3", "-m", "pip", "install", "virtualenv"])
-        subprocess.call(["python3", "-m", "virtualenv", os.path.join(project_dir, ".venv")])
+        subprocess.call(["python3", "-m", "virtualenv", os.path.join(project_dir, "venv")])
         subprocess.call(["make", "install", "-C", project_dir])
 
     def _replace_in_file(self, dir_name, filename, args):
