@@ -1,13 +1,12 @@
+__copyright__ = "Copyright (c) 2018 Helium Edu"
+__license__ = "MIT"
+
 import os
 
 import git
 
 from .. import utils
 
-__author__ = "Alex Laird"
-__copyright__ = "Copyright 2018, Helium Edu"
-__version__ = "1.5.0"
-
 
 class ListBuildsAction:
     def __init__(self):
@@ -26,7 +25,7 @@ class ListBuildsAction:
         if config["projectsRelativeDir"] != ".":
             root_dir = os.path.abspath(os.path.join(projects_dir, ".."))
             if os.path.exists(os.path.join(root_dir, ".git")):
-                print(utils.get_repo_name(root_dir))
+                print(utils.get_repo_name(root_dir, config["remoteName"]))
 
                 repo = git.Repo(root_dir)
                 repo.git.fetch(tags=True, prune=True)
