@@ -1,34 +1,37 @@
+__copyright__ = "Copyright (c) 2018 Helium Edu"
+__license__ = "MIT"
+
 import os
 import re
 import subprocess
 import sys
+import threading
 from builtins import input
 
 import yaml
 
-from .settings import VERSION, get_default_settings
-
-__author__ = "Alex Laird"
-__copyright__ = "Copyright 2018, Helium Edu"
-__version__ = "1.5.0"
+from . import __version__
+from .settings import get_default_settings
 
 _config_cache = None
 
+config_file_lock = threading.Lock()
+
 
 def get_title():
-    return """\
-    __         ___                            ___
+    return f"""    __         ___                            ___
    / /_  ___  / (_)_  ______ ___        _____/ (_)
-  / __ \/ _ \/ / / / / / __ `__ \______/ ___/ / /
+  / __ \\/ _ \\/ / / / / / __ `__ \\______/ ___/ / /
  / / / /  __/ / / /_/ / / / / / /_____/ /__/ / /
-/_/ /_/\___/_/_/\__,_/_/ /_/ /_/      \___/_/_/
-                                              v{}
-""".format(VERSION)
+/_/ /_/\\___/_/_/\\__,_/_/ /_/ /_/      \\___/_/_/
+                                              v{__version__}
+"""
 
 
 def _save_config(config_path, config):
-    with open(config_path, "w") as config_file:
-        yaml.safe_dump(config, config_file)
+    with config_file_lock:
+        with open(config_path, "w") as config_file:
+            yaml.safe_dump(config, config_file)
 
 
 def get_config(init=False):
@@ -41,16 +44,16 @@ def get_config(init=False):
             if not init:  # pragma: no cover
                 response = input("No config file found; initialize a new project [Y/n]? ")
                 if response.lower() not in ["y", "yes", ""]:
-                    print("\nThis tool cannot be used without a config file.\n")
-
+                    print("\nError: this tool cannot be used without a config file.\n")
                     sys.exit(1)
                 else:
                     print("")
 
             _save_config(config_path, get_default_settings())
 
-        with open(config_path, "r") as lines:
-            _config_cache = yaml.safe_load(lines)
+        with config_file_lock:
+            with open(config_path, "r") as lines:
+                _config_cache = yaml.safe_load(lines)
     else:
         # Ensure cache is up to date
         updated = False
@@ -77,7 +80,7 @@ def get_projects_dir():
 def parse_hosts_file(env):
     hosts_str = subprocess.Popen(["ansible", "all", "-i", os.path.join("hosts", env), "--list-hosts"],
                                  cwd=get_ansible_dir(), stdin=subprocess.PIPE, stdout=subprocess.PIPE,
-                                 bufsize=1).stdout.read().decode("utf-8")
+                                 bufsize=0).stdout.read().decode("utf-8")
 
     hosts = []
     for line in hosts_str.split("\n")[1:]:
@@ -98,15 +101,18 @@ def should_update(line, verification, start_needle, end_needle=""):
 
 
 def get_copyright_name():  # pragma: no cover
-    with open(os.path.join(get_ansible_dir(), "group_vars", "all.yml"), "r") as lines:
-        data = yaml.safe_load(lines)
-        return data[get_config()["ansibleCopyrightNameVar"]]
+    if get_config()["copyrightName"]:
+        return get_config()["copyrightName"]
+    else:
+        with open(os.path.join(get_ansible_dir(), "group_vars", "all.yml"), "r") as lines:
+            data = yaml.safe_load(lines)
+            return data[get_config()["ansibleCopyrightNameVar"]]
 
 
-def get_repo_name(repo_dir):  # pragma: no cover
-    remote_url_str = subprocess.Popen(["git", "config", "--get", "remote.origin.url"], cwd=repo_dir,
+def get_repo_name(repo_dir, remote_name):  # pragma: no cover
+    remote_url_str = subprocess.Popen(["git", "config", "--get", f"remote.{remote_name}.url"], cwd=repo_dir,
                                       stdin=subprocess.PIPE, stdout=subprocess.PIPE,
-                                      bufsize=1).stdout.read().decode("utf-8")
+                                      bufsize=0).stdout.read().decode("utf-8")
     return os.path.basename(remote_url_str.strip()).rstrip(".git")
 
 
@@ -119,11 +125,11 @@ def sort_tags(tags):
     version_tags = []
 
     for git_tag in tags:
-        cleaned_tag = git_tag.tag.tag.lstrip("v")
-        pattern = re.compile("^[0-9\.]*$")
+        cleaned_tag = git_tag.name.lstrip("v")
+        pattern = re.compile("^[0-9\\.]*$")
         if pattern.match(cleaned_tag):
             version_tags.append(git_tag)
 
-    version_tags.sort(key=lambda v: list(map(int, v.tag.tag.lstrip("v").split("."))))
+    version_tags.sort(key=lambda v: list(map(int, v.name.lstrip("v").split("."))))
 
     return version_tags
